@@ -3,7 +3,7 @@
 from dataclasses import dataclass
 from typing import Dict
 
-from .FireMapTileStatusV1 import FireMapTileStatusV1
+from . import FireMapTileV1
 
 
 @dataclass
@@ -15,6 +15,4 @@ class FireMapTileBlockV1:
     tlng: float  # To longitude
     tlat: float  # To latitude
 
-    clear: Dict[str, FireMapTileStatusV1]  # Map with clear tiles
-    smoke: Dict[str, FireMapTileStatusV1]  # Map with smoke tiles
-    fire: Dict[str, FireMapTileStatusV1]  # Map with fire tiles
+    tiles: Dict[str, FireMapTileV1]  # Map tiles
