@@ -1,10 +1,9 @@
 # -*- coding: utf-8 -*-
 
-__all__ = ['FireMapUpdateTypeV1', 'FireMapTileStatusV1', 'FireMapTileV1',
+__all__ = ['FireMapUpdateTypeV1', 'FireMapTileV1',
            'FireMapUpdateV1', 'FireMapTileBlockV1', 'FireMapZoomV1',
            'LocationV1', 'FireMapUpdateV1Schema']
 
-from .FireMapTileStatusV1 import FireMapTileStatusV1
 from .FireMapTileV1 import FireMapTileV1
 from .FireMapUpdateTypeV1 import FireMapUpdateTypeV1
 from .FireMapTileBlockV1 import FireMapTileBlockV1
