@@ -1,19 +1,19 @@
 # -*- coding: utf-8 -*-
 
 import datetime
-from threading import Lock
 
-from typing import Optional, List, Dict
+from typing import Optional, List
 
 from pip_services3_commons.commands import ICommandable, CommandSet
 from pip_services3_commons.config import IConfigurable, ConfigParams
+from pip_services3_commons.convert import JsonConverter
 from pip_services3_commons.data import FilterParams, PagingParams
 from pip_services3_commons.refer import IReferenceable, IReferences, Descriptor
+from pip_services3_messaging.queues import IMessageQueue, MessageEnvelope
 
 from .FireMapCommandSet import FireMapCommandSet
 from .IFireMapController import IFireMapController
-from ..data.version1 import LocationV1, FireMapTileV1, FireMapUpdateV1, FireMapZoomV1, \
-    FireMapUpdateTypeV1
+from ..data.version1 import LocationV1, FireMapTileV1, FireMapUpdateV1, FireMapZoomV1, FireMapUpdateTypeV1
 from ..data.version1.FireMapTileBlockV1 import FireMapTileBlockV1
 from ..map_utils import FireMapUtil
 from ..persistence.IFireMapPersistence import IFireMapPersistence
@@ -24,8 +24,7 @@ class FireMapController(IFireMapController, IConfigurable, IReferenceable, IComm
     def __init__(self):
         self.__persistence: IFireMapPersistence = None
         self.__command_set: FireMapCommandSet = None
-
-        self.__lock = Lock()
+        self.__message_queue: IMessageQueue = None
 
     def configure(self, config: ConfigParams):
         pass
@@ -34,6 +33,10 @@ class FireMapController(IFireMapController, IConfigurable, IReferenceable, IComm
         self.__persistence = references.get_one_required(Descriptor(
             'eic-stopfires-services-firemap', 'persistence', '*', '*', '1.0'))
 
+        self.__message_queue = references.get_one_optional(
+            Descriptor('pip-services', 'message-queue', '*', '*', '1.0')
+        )
+
     def get_command_set(self) -> CommandSet:
         self.__command_set = self.__command_set or FireMapCommandSet(self)
         return self.__command_set
@@ -59,7 +62,6 @@ class FireMapController(IFireMapController, IConfigurable, IReferenceable, IComm
 
     def update_tiles(self, correlation_id: Optional[str], updates: List[FireMapUpdateV1]):
         coordinates = []
-        result_blocks: Dict[str, FireMapTileBlockV1] = {}
 
         for update in updates:
             coordinates.append(f'{update.lat};{update.long}')
@@ -73,14 +75,19 @@ class FireMapController(IFireMapController, IConfigurable, IReferenceable, IComm
         absent_zooms: List[int] = [e.value for e in FireMapZoomV1]
 
         for update in updates:
-            current_update_blocks = []
+            current_update_blocks: List[FireMapTileBlockV1] = []
 
+            index = 0
             for block in update_blocks:
                 # check if update coordinates in block coordinates
                 if block.flng <= update.long <= block.tlng and block.tlat <= update.lat <= block.flat:
                     # find absent zooms
                     current_update_blocks.append(block)
                     absent_zooms = list(filter(lambda z: z != block.zoom, absent_zooms))
+                    update_blocks[index] = None
+                index += 1
+
+            update_blocks = list(filter(lambda e: e is not None, update_blocks))
 
             # if block is not created, or some absent
             if len(absent_zooms) > 0:
@@ -127,19 +134,13 @@ class FireMapController(IFireMapController, IConfigurable, IReferenceable, IComm
                 block.tiles[id].people = update.time
                 block.tiles[id].people_count = people_count
 
-            for block in current_update_blocks:
-                result_blocks[block.id] = block
+                if self.__message_queue is not None:
+                    message = MessageEnvelope(correlation_id, 'FireMapTileV1', JsonConverter.to_json(block.tiles[id]))
+                    self.__message_queue.send(correlation_id, message)
 
-            update_blocks = result_blocks.values()
+            update_blocks.extend(current_update_blocks)
 
-            # TODO: add update listener
-
-        self.__persistence.update_tile_blocks(correlation_id, list(result_blocks.values()))
-
-        # with self.__lock:
-        #     threading.Thread(target=self.__persistence.update_tile_blocks,
-        #                      args=(correlation_id, list(result_blocks.values())),
-        #                      name=f'Mongo call update: {len(result_blocks)} items').start()
+        self.__persistence.update_tile_blocks(correlation_id, update_blocks)
 
     def __create_blocks(self, lat: float, long: float, zooms: List[int]) -> List[FireMapTileBlockV1]:
         blocks: List[FireMapTileBlockV1] = []
@@ -235,7 +236,7 @@ class FireMapController(IFireMapController, IConfigurable, IReferenceable, IComm
                     child_block.tiles[id] = self.__default_datetime(child_block.tiles[id], True)
                     return True
 
-                child_block.tiles[id] = self.__default_datetime(child_block.tiles[id])
+                child_block.tiles[id] = self.__default_datetime(child_block.tiles[id], True)
 
         # if checked all blocks
         return count_of_tiles == checked
@@ -257,4 +258,4 @@ class FireMapController(IFireMapController, IConfigurable, IReferenceable, IComm
                 tile.smoke = default
             if not tile.fire:
                 tile.fire = default
-        return tile
\ No newline at end of file
+        return tile
