@@ -59,19 +59,53 @@ class FireMapMongoDbPersistence(IdentifiableMongoDbPersistence, IFireMapPersiste
 
             criteria = [{'$or': criteria}]
 
-        if flng and tlng:
-            criteria.extend([{'flng': {'$gte': flng, '$lte': tlng}}, {'tlng': {'$gte': flng, '$lte': tlng}}])
+        if flng and tlng and flat and tlat:
+            # check intersections of tile block in passed coordinates
+            criteria2 = None
 
             if flng2 and tlng2:
-                criteria.extend([{'flng': {'$gte': flng2, '$lte': tlng2}}, {'tlng': {'$gte': flng2, '$lte': tlng2}}])
+                criteria2 = self.__compose_intersect_request(flng2, tlng2, 'lng')
+
+            criteria.extend(self.__compose_intersect_request(flng, tlng, 'lng'))
+
+            if criteria2:
+                criteria.extend(criteria2)
                 criteria = [{'$or': criteria}]
 
-        if flat and tlat:
-            criteria.extend([{'flat': {'$gte': flat, '$lte': tlat}}, {'tlat': {'$gte': flat, '$lte': tlat}}])
+            criteria.extend(self.__compose_intersect_request(flat, tlng, 'lat'))
+
         if zoom:
             criteria.append({'zoom': zoom})
+
         return None if len(criteria) < 1 else {'$and': criteria}
 
+    def __compose_intersect_request(self, point1: float, point2: float, type_coord: str) -> List[dict]:
+        request: List[dict] = []
+
+        if type_coord == 'lat':
+            request = [
+                {
+                    '$or': [
+                        {'$and': [{'flat': {'$lte': point1}}, {'flat': {'$gte': point2}}, {'tlat': {'$lte': point2}}]},
+                        {'flat': {'$gte': point1}, 'tlat': {'$lte': point2}},
+                        {'flat': {'$gte': point1}, 'tlat': {'$lte': point1}},
+                        {'flat': {'$lte': point1}, 'tlat': {'$gte': point2}},
+                    ]
+                }
+            ]
+        elif type_coord == 'lng':
+            request = [
+                {
+                    '$or': [
+                        {'$and': [{'flng': {'$gte': point1}}, {'flng': {'$lte': point2}}, {'tlng': {'$gte': point2}}]},
+                        {'flng': {'$lte': point1}, 'tlng': {'$gte': point2}},
+                        {'flng': {'$lte': point1}, 'tlng': {'$gte': point1}},
+                        {'flng': {'$gte': point1}, 'tlng': {'$lte': point2}},
+                    ]
+                }
+            ]
+        return request
+
     def get_tile_blocks_by_filter(self, correlation_id: Optional[str], filter: FilterParams,
                                   paging: PagingParams) -> DataPage:
         # get blocks in passed coordinates
